pub struct ClientData {
pub client_id: String,
pub client_name: String,
pub sla_id: Option<String>,
}Expand description
The information regarding the client that was authenticated or authorized.
Fields
client_id: StringThe client id validated, it is the same as the one provided in the validation.
client_name: StringThe client name associated with validated client.
sla_id: Option<String>The SLA associated to the client id.